/***************************************************************************
                          ann_ds_rnd.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_DS_RND_H
#define __ANN_DS_RND_H

#include <ann_ds_rec.h>

namespace ANN
{

  class DS_rnd;
  
  //              //
 // class DS_rnd //
//              //

  class DS_rnd : public DS_rec
  {
  private:
    DS_rnd();

  protected:
    size_t *perm;
    size_t *perm_;
    size_t  perm_len;
    size_t  current;

  public:
    DS_rnd(DS &orig_);
    virtual ~DS_rnd();
    
    virtual bool   reset();
    virtual void   feed();
    virtual bool   seek(size_t term_pos_);
    virtual bool   locate(const Loc &loc);
    virtual size_t which() const;
  };
  
} // namespace ANN

#endif /* __ANN_DS_RND_H */
